
[![Build Status](https://travis-ci.org/adbharadwaj/graphspace-python.svg?branch=master)](https://travis-ci.org/adbharadwaj/graphspace-python)
[![PyPI version](https://badge.fury.io/py/graphspace_python.svg)](https://badge.fury.io/py/graphspace_python)


## GraphSpace Python Client

A Python library for the GraphSpace REST API. It simplifies the process of authentication, request construction, and response parsing for Python developers using the GraphSpace API. This clientlib is built and tested on Python 2.7.
